@@ -1,9 +1,14 @@
 use clap::Parser;
 
 mod args;
+mod controller;
 mod game;
+mod keyboard;
+mod letters;
+mod state;
 
 use args::{App, GameMode};
+use controller::GameController;
 use game::Game;
 use rand::Rng;
 
@@ -18,7 +23,8 @@ fn main() -> color_eyre::Result<()> {
         Some(GameMode::Random) => Game::from_day(rand::thread_rng().gen())?,
     };
 
-    if let Some(share) = game.start()? {
+    let controller = GameController::new(game)?;
+    if let Some(share) = controller.run()? {
         println!("{}", share);
     }
 
