@@ -2,33 +2,41 @@ use std::fmt::Display;
 
 pub mod words;
 
+/// Gets the solution word for the given day
 pub fn get_solution(day: usize) -> &'static str {
     words::FINAL[day % words::FINAL.len()]
 }
 
+/// Gets the current day number from the given date
 pub fn get_day(date: time::Date) -> usize {
     (date.to_julian_day() - words::FIRST_DAY.to_julian_day()) as usize
 }
 
+/// Determines if the given word is valid, according to the default word lists
 pub fn valid(word: &str) -> bool {
     words::ACCEPT.contains(&word) || words::FINAL.contains(&word)
 }
 
 #[derive(Clone, Copy, Debug, PartialEq)]
+/// Represents a match for a given letter against the solution
 pub enum Match {
-    Green,
-    Amber,
-    Black,
+    /// Letter is in the correct position
+    Exact,
+    /// Letter is in the solution but not in the correct positon
+    Close,
+    /// Letter is not in the solution
+    Wrong,
 }
 
+/// Represents the outcome for a single guess
 pub struct Matches(pub [Match; 5]);
 
 impl Display for Match {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Match::Green => write!(f, "🟩"),
-            Match::Amber => write!(f, "🟨"),
-            Match::Black => write!(f, "⬛"),
+            Match::Exact => write!(f, "🟩"),
+            Match::Close => write!(f, "🟨"),
+            Match::Wrong => write!(f, "⬛"),
         }
     }
 }
@@ -54,26 +62,42 @@ pub fn diff(input: &str, solution: &str) -> Matches {
     let input = input.as_bytes();
     let mut solution = solution.as_bytes().to_owned();
 
-    let mut diff = [Match::Black; 5];
+    let mut diff = [Match::Wrong; 5];
 
     // find exact matches first
     for (i, &b) in input.iter().enumerate() {
         if solution[i] == b {
             solution[i] = 0; // letters only match once
-            diff[i] = Match::Green;
+            diff[i] = Match::Exact;
         }
     }
 
     // now, find amber matches
     for (i, &b) in input.iter().enumerate() {
-        if diff[i] != Match::Black {
+        if diff[i] != Match::Wrong {
             continue;
         }
         if let Some(j) = solution.iter().position(|&x| x == b) {
             solution[j] = 0; // letters only match once
-            diff[i] = Match::Amber;
+            diff[i] = Match::Close;
         }
     }
 
     Matches(diff)
 }
+
+#[cfg(test)]
+mod tests {
+    #[test]
+    fn diff() {
+        use super::Match::{self, *};
+        let table: [(&str, &str, [Match; 5]); 3] = [
+            ("class", "crest", [Exact, Wrong, Wrong, Exact, Wrong]),
+            ("stars", "crest", [Close, Close, Wrong, Close, Wrong]),
+            ("kills", "skill", [Close, Close, Close, Exact, Close]),
+        ];
+        for (input, solution, matches) in table {
+            assert_eq!(super::diff(input, solution).0, matches);
+        }
+    }
+}
